@@ -157,7 +157,7 @@ APPKIT_EXPORT NSString *GSScreenNumber;
 - (void) docedited: (int) edited : (int)win;
 - (void) setinputstate: (int)state : (int)win;
 - (void) setinputfocus: (int)win;
-- (void) setalpha: (float)alpha: (int)win;
+- (void) setalpha: (float)alpha : (int)win;
 - (void) setShadow: (BOOL)hasShadow : (int)win;
 
 - (NSPoint) mouselocation;
@@ -175,6 +175,7 @@ APPKIT_EXPORT NSString *GSScreenNumber;
 - (void) freecursor: (void*) cid;
 - (void) setParentWindow: (int)parentWin 
           forChildWindow: (int)childWin;
+- (void) setIgnoreMouse: (BOOL)ignoreMouse : (int)win;
 
 @end
 
@@ -189,6 +190,7 @@ APPKIT_EXPORT NSString *GSScreenNumber;
 - (void) discardEventsMatchingMask: (unsigned)mask
 		       beforeEvent: (NSEvent*)limit;
 - (void) postEvent: (NSEvent*)anEvent atStart: (BOOL)flag;
+- (void) _printEventQueue;
 @end
 
 
